/*******************************************************************************
* File Name: WaveDAC8_PM.c  
* Version 1.60
*
* Description:
*  This file provides the power manager source code to the API for 
*  the WaveDAC8 component.
*
* Note: 
*
*******************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "WaveDAC8.h"

// static WaveDAC8_BACKUP_STRUCT  WaveDAC8_backup;


/*******************************************************************************
* Function Name: WaveDAC8_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration.
*  
* Parameters:  
*  void.
*
* Return: 
*  void.
*
* Reentrant:
*  No
*
*******************************************************************************/
void WaveDAC8_SaveConfig(void)
{
    /* Nothing to save before entering into sleep mode as all the registers used 
       here are retension registers. */
}


/*******************************************************************************
* Function Name: WaveDAC8_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void.
*
* Return: 
*  void
*
* Reentrant:
*  No
*
*******************************************************************************/
void WaveDAC8_RestoreConfig(void)
{
    /* Nothing to restore */
}


/*******************************************************************************
* Function Name: WaveDAC8_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves its configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  WaveDAC8_backup:  The structure field 'enableState' is modified 
*  depending on the enable state of the block before entering to sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void WaveDAC8_Sleep(void)
{
#if(WaveDAC8_DACMODE == WaveDAC8_VOLT_MODE)
   WaveDAC8_VDAC8_Sleep();
#else
   WaveDAC8_IDAC8_Sleep();
#endif

}


/*******************************************************************************
* Function Name: WaveDAC8_Wakeup
********************************************************************************
*
* Summary:
*  Enables block's operation and restores its configuration. Should be called
*  just after awaking from sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  void
*
* Global variables:
*  WaveDAC8_backup:  The structure field 'enableState' is used to 
*  restore the enable state of block after wakeup from sleep mode.
*
* Reentrant:
*  No
*
*******************************************************************************/
void WaveDAC8_Wakeup(void) 
{
#if(WaveDAC8_DACMODE == WaveDAC8_VOLT_MODE)
   WaveDAC8_VDAC8_Wakeup();
#else
   WaveDAC8_IDAC8_Wakeup();
#endif

}


/* [] END OF FILE */



